// Interface de premier niveau pour le dveloppement de plugin pour PhotoFiltre
// Version 1.0 / Avril 2004 / Copyright Benjamin FOURNIER
// Base sur la version Delphi 1.4 / Avril 2004 / Copyright Antonio Da Cruz
// La structure TPlgImage est propose par PF
// Merci de ne pas modifier les sources sans mon autorisation !

#ifndef PlgIntH
#define PlgIntH

#include <windows.h>

#define MaxLongStr 255
#define MaxShortStr 63

// type du plugin
#define PT_FILTER 0
#define PT_IMAGE 1
#define PT_FILE_IMPORT 2
#define PT_FILE_EXPORT 3
#define PT_TOOL 4

// mode de dialogue
#define DM_MODAL 0
#define DM_PREVIEW 1
#define DM_COLOR_PICKER 2

// flags de slection
#define SF_AUTO 0
#define SF_NONE 1

// flags pour la cration d'image
#define IF_CREATE 0
#define IF_FILE 1

// flags pour l'activation du menu
#define MF_RGB_COLORS 0x1
#define MF_INDEXED_COLORS 0x2
#define MF_TRANSPARENT 0x4
#define MF_NOT_TRANSPARENT 0x8
#define MF_SELECTED 0x10
#define MF_NOT_SELECTED 0x20
#define MF_NEED_IMAGE 0x40
#define MF_NEED_MORE_THAN_ONE_IMAGE 0x80
// test sur l'extension du fichier en cours
#define MF_IMAGE_JPEG 0x10000
#define MF_IMAGE_GIF 0x20000
#define MF_IMAGE_PNG 0x40000
#define MF_IMAGE_BMP 0x80000
#define MF_IMAGE_TIFF 0x100000
#define MF_IMAGE_PFS 0x200000

// Compatibilit Delphi/Non Delphi
#define	DELPHI  1
#define	NON_DELPHI 2

// en remplacement des types Delphi
typedef enum {clMin=-0x7fffffff-1, clMax=0x7fffffff} TDColor;
typedef void *TDBitmap;
typedef void *TDForm;

// structure pour rcuprer les infos sur traduction
typedef struct
{
  char Code[4];
  char Language[MaxShortStr + 1];
  int Flags;
} TPluginLanguage;
typedef TPluginLanguage *PPluginLanguage;

// structure d'entte du plugin
typedef struct
{
  char Caption[MaxShortStr + 1];
  char Version[MaxShortStr + 1];
  int PluginType;
  char Author[MaxShortStr + 1];
  char Comment[MaxLongStr + 1];
  char Reserved[MaxLongStr + 1];
  int Flags;
} TPluginHeader;
typedef TPluginHeader *PPluginHeader;

// permet d'encapsuler un objet TBitmap Delphi (compatibilit de niveau 2)
typedef struct
{
  int piSize; // taille de la structure
  int piWidth; // largeur en pixels
  int piHeight; // hauteur en pixels
  int piWidthSize; // taille X utile en octets (piWidth * piByteCount)
  int piScanlineSize; // scanline complete en octets (alignement 32 bits)
  int piByteCount; // nombre d'octets par pixels
  int piDataSize; // taille totale du buffer (piScanlineSize * piHeight)
  void *piBuffer; // adresse du buffer de travail
  TDBitmap* piBitmap; // pointeur vers un objet TBitmap Delphi
  HBITMAP piHandle; // handle du bitmap Windows
} TPlgImage;
typedef TPlgImage *PPlgImage;

// types pour la structure d'xcution
// (tout niveau de compatibilit)
typedef void __stdcall (*TSimpleProc)(void);
typedef void __stdcall (*TBeginFilterProc)(char *pMsg, BOOL ChangeCursor);
typedef BOOL __stdcall (*TGetBitmapProc)(TDBitmap* Bitmap);
typedef BOOL __stdcall (*TSetBitmapProc)(TDBitmap* Bitmap);
typedef BOOL __stdcall (*TGetSelBitmapProc)(TDBitmap* Bitmap);
typedef BOOL __stdcall (*TSetSelBitmapProc)(TDBitmap* Bitmap, int SelFlag);
typedef TDColor __stdcall (*TGetTransparentColor)(void);
typedef BOOL __stdcall (*TSetTransparentColor)(TDColor Color);
typedef int __stdcall (*TGetColorCount)(void);
typedef int __stdcall (*TSetColorCount)(int ColorCount);
typedef BOOL __stdcall (*TNewImage)(TDBitmap* Bitmap, char * pFileName,
  int Flag, int ColorCount, TDColor TransColor);
typedef void __stdcall (*TShowFormProc)(TDForm* Form, int Mode,
  BOOL MainFormCenter, BOOL CloseWaiting);
typedef BOOL __stdcall (*TSetAlphaBlendProc)(int Alpha);
typedef BOOL __stdcall (*TDrawSelBorder)(int Width, TDColor Color,
  BOOL Antialias);
typedef BOOL __stdcall (*TGetSelMask)(TDBitmap* Bitmap);
typedef char * __stdcall (*TGetStr)(char *pBuffer, int MaxSize);
typedef BOOL __stdcall (*TSetStr)(char *pBuffer);
typedef BOOL __stdcall (*TGetBitmapByName)(TDBitmap* Bitmap, char *pFileName);
typedef BOOL __stdcall (*TGetThumb)(TDBitmap* Bitmap, TDColor BkColor,
  int BorderSize, int ShadowSize, TDColor ShadowBkColor, RECT *R);
typedef BOOL __stdcall (*TGetThumbByName)(TDBitmap* Bitmap, char *pFileName,
  TDColor BkColor, int BorderSize, int ShadowSize, TDColor ShadowBkColor,
  RECT *R);
typedef BOOL __stdcall (*TEnumImageProc)(char * pFileName, int Width,
  int Height, int NbColors, TDColor TransColor);
typedef BOOL __stdcall (*TEnumImages)(TEnumImageProc EnumImageProc);

// compatibilit de niveau >= 2
typedef void __stdcall (*TPrepareDialogProc)(HWND Handle, int Mode,
  BOOL MainFormCenter, BOOL CloseWaiting);
typedef int __stdcall (*TCreateDBmpProc)(PPlgImage pImg);
typedef int __stdcall (*TFreeDBmpProc)(PPlgImage pImg);
typedef HBITMAP __stdcall (*TReleaseHandleDBmpProc)(PPlgImage pImg);
typedef void * __stdcall (*TGetScanLineDBmpProc)(PPlgImage pImg, int Row);

// structure d'excution
typedef struct
{
  HWND MainHandle;
  BOOL ImageExists;
  BOOL Selected;
  RECT SelRect;
  RECT ImgRect;
  BOOL XP_ThemesEnabled;
  TBeginFilterProc BeginFilter;
  TSimpleProc EndFilter;
  TGetBitmapProc GetBitmap;
  TSetBitmapProc SetBitmap;
  TGetSelBitmapProc GetSelBitmap;
  TSetSelBitmapProc SetSelBitmap;
  TGetTransparentColor GetTransparentColor;
  TSetTransparentColor SetTransparentColor;
  TGetColorCount GetColorCount;
  TSetColorCount SetColorCount;
  TNewImage NewImage;
  TShowFormProc ShowForm;
  TSetAlphaBlendProc SetAlphaBlend;
  TDrawSelBorder DrawSelBorder;
  TGetSelMask GetSelMask;
  TSimpleProc ResetSaveMenu;
  TGetStr GetImgFileName;
  TGetStr GetExePath;
  TGetStr GetOpenPath;
  TGetStr GetSavePath;
  TGetStr GetPluginPath;
  TGetStr GetIniFile;
  TSetStr SetImgFileName;
  TGetBitmapByName GetBitmapByName;
  TGetThumb GetThumb;
  TGetThumbByName GetThumbByName;
  TEnumImages EnumImages;
  TPrepareDialogProc PrepareDialog;
  TCreateDBmpProc CreateDBmp;
  TFreeDBmpProc FreeDBmp;
  TReleaseHandleDBmpProc ReleaseHandleDBmp;
  TGetScanLineDBmpProc GetScanlineDBmp;
  int Reserved[10];
} TPluginStruct;
typedef TPluginStruct *PPluginStruct;

// variables globales
extern TPluginLanguage PluginLanguage;
extern TPluginHeader PluginHeader;
extern TPluginStruct PluginStruct;

#endif
