// Effet miroir sur une image

// Copyright Antonio DA CRUZ - Janvier 2004
// Merci de ne pas modifier les sources sans mon autorisation !

unit Params;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, ExtCtrls;

type
  TParamsForm = class(TForm)
    BtnCancel: TButton;
    BtnOk: TButton;
    RdbBas: TRadioButton;
    RdbDroite: TRadioButton;
    Image1: TImage;
    Image2: TImage;
    Bevel1: TBevel;
    procedure BtnOkClick(Sender: TObject);
    procedure BtnCancelClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormKeyPress(Sender: TObject; var Key: Char);
  private
    procedure DoAction;
  public
    DialogResult: Boolean;
  end;

var
  ParamsForm: TParamsForm;

implementation

uses
  Plugin;

{$R *.dfm}

procedure TParamsForm.FormCreate(Sender: TObject);
begin
  // traduction
  if GetLanguageCode <> 'FR' then
  begin
    Caption := 'Mirror effect';
    BtnCancel.Caption := 'Cancel';
    RdbDroite.Caption := 'Assemble at right';
    RdbBas.Caption := 'Assemble at bottom';
  end;
  ActiveControl := BtnOk;
  RdbDroite.Checked := True;
end;

procedure TParamsForm.DoAction;
var
  BmpSrc, BmpDest: TBitmap;
  W, H: Integer;
  RSrc, RDest: TRect;
begin
  // dimensions de l'image en cours
  W := GetImgWidth;
  H := GetImgHeight;
  BmpSrc := TBitmap.Create;
  BmpDest := TBitmap.Create;
  try
    BeginFilter;
    // rcupre l'image en cours
    BmpSrc.PixelFormat := pf24bit;
    BmpSrc.Width := W;
    BmpSrc.Height := H;
    CheckPluginFunc(GetBitmap(BmpSrc));
    // les dimensions de l'image rsultat dpendent de l'axe
    BmpDest.PixelFormat := pf24bit;
    if RdbBas.Checked then
    begin
      BmpDest.Width := W;
      BmpDest.Height := 2 * H;
    end
    else
    begin
      BmpDest.Width := 2 * W;
      BmpDest.Height := H;
    end;
    // recopie les pixels source
    RSrc := Rect(0, 0, W, H);
    BmpDest.Canvas.CopyRect(RSrc, BmpSrc.Canvas, RSrc);
    // recopie en inversant
    if RdbBas.Checked then RDest := Rect(0, 2 * H - 1, W, H - 1)
    else RDest := Rect(2 * W - 1, 0, W - 1, H);
    BmpDest.Canvas.CopyRect(RDest, BmpSrc.Canvas, RSrc);
    // affecte le nouveau bitmap  l'image en cours
    // (ne change ni la transparence ni le nombre de couleurs)
    CheckPluginFunc(SetBitmap(BmpDest));
  finally
    BmpSrc.Free;
    BmpDest.Free;
    EndFilter;
  end;
end;

procedure TParamsForm.BtnOkClick(Sender: TObject);
begin
  DoAction;
  DialogResult := True;
  Close;
end;

procedure TParamsForm.BtnCancelClick(Sender: TObject);
begin
  Close;
end;

// Actions via le clavier (KeyPreview  True)
procedure TParamsForm.FormKeyPress(Sender: TObject; var Key: Char);
begin
  if Key = #27 then Close
  else if Key = #13 then BtnOkClick(Sender);
end;

end.
